plot.mrCA: Plot factor plan resulting from multiple-response...

View source: R/plot.mrCA.R

plot.mrCAR Documentation

Plot factor plan resulting from multiple-response Correspondence Analysis (MR-CA).

Description

This function plots the results coming from mrCA.

Usage

## S3 method for class 'mrCA'
plot(
  x,
  axes = c(1, 2),
  alpha.total.bootstrap.test = 0.05,
  alpha.ellipse = alpha.total.bootstrap.test,
  select.rep = rownames(x$col.coord),
  rev.x = FALSE,
  rev.y = FALSE,
  size.points = 3.5,
  size.lab = 6,
  size.head.arrow = 0.4,
  expansion = 1.25,
  title = NULL,
  ...
)

Arguments

x

A list returned by mrCA.

axes

Which dimensions of the MR-CA should be plotted?

alpha.total.bootstrap.test

The alpha risk of the total bootstrap tests. Only useful if the MR-CA was computed using mrCA and ellipse=TRUE. See details.

alpha.ellipse

The alpha risk of the confidence ellipses. Only useful if the MR-CA was computed using mrCA and ellipse=TRUE.

select.rep

A character vector specifying the response options to plot. By default, all response options are plotted.

rev.x

Should the horizontal plotted dimension be reversed? Useful in case of map comparisons to align categories.

rev.y

Should the vertical plotted dimension be reversed? Useful in case of map comparisons to align categories.

size.points

The size of the points used to represent the categories on the map.

size.lab

The size of the label on the map.

size.head.arrow

The size of the head of the arrows used to represent the response options on the map.

expansion

The factor of expansion applied to response options coordinates to increase readability.

title

An optional title to be added to the plot.

...

further arguments passed to or from other methods.

Details

  • alpha.total.bootstrap.test: Categories non-significantly different at the alpha risk of alpha.total.bootstrap.test according to the total bootstrap test are linked by a line on the plot. If these links are not required, alpha.total.bootstrap.test can be set to 1.

Value

A MR-CA factor map.

Examples

nb.obs=200
nb.response=5
nb.category=5
vec.category=paste("C",1:nb.category,sep="")
right=matrix(rbinom(nb.response*nb.obs,1,0.25),nb.obs,nb.response)
category=sample(vec.category,nb.obs,replace = TRUE)
dset=cbind.data.frame(category,right)
dset$category=as.factor(dset$category)

res=mrCA(dset)

plot(res)

MultiResponseR documentation built on March 23, 2026, 5:07 p.m.