View source: R/plot.sensory.mr.sig.cell.R
| plot.sensory.mr.sig.cell | R Documentation |
This function plots the results coming from sensory.mr.sig.cell.
## S3 method for class 'sensory.mr.sig.cell'
plot(
x,
alpha.1 = 0.05,
alpha.2 = 0,
choice = "percent.derived.cont",
col.greater.1 = "green3",
col.lower.1 = "orangered",
col.greater.2 = "lightgreen",
col.lower.2 = "lightsalmon",
...
)
x |
A list returned by |
alpha.1 |
The alpha risk to consider the tests as significant. |
alpha.2 |
The alpha risk to consider the tests as showing a trend. If trends are not to be considered, alpha.2 can be set to 0 (Default). |
choice |
Which table from res should be plotted? Default is percent.derived.cont. |
col.greater.1 |
The color used to highlight significant positive associations. |
col.lower.1 |
The color used to highlight significant negative associations. |
col.greater.2 |
The color used to highlight positive associations showing a trend. |
col.lower.2 |
The color used to highlight negative associations showing a trend. |
... |
further arguments passed to or from other methods. |
A table with cells highlighted.
data(milkchoc)
dim.sig=sensory.mr.dimensionality.test(milkchoc)$dim.sig
res=sensory.mr.sig.cell(milkchoc,nbaxes.sig=dim.sig)
plot(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.