plot.sensory.mrCA: Plot factor plan resulting from multiple-response...

View source: R/plot.sensory.mrCA.R

plot.sensory.mrCAR Documentation

Plot factor plan resulting from multiple-response Correspondence Analysis (MR-CA) applied on sensory data

Description

This function plots the results coming from sensory.mrCA.

Usage

## S3 method for class 'sensory.mrCA'
plot(
  x,
  axes = c(1, 2),
  alpha.total.bootstrap.test = 0.05,
  alpha.ellipse = alpha.total.bootstrap.test,
  select.desc = rownames(x$desc.coord),
  rev.x = FALSE,
  rev.y = FALSE,
  size.points = 3.5,
  size.lab = 6,
  size.head.arrow = 0.4,
  expansion = 1.25,
  title = NULL,
  ...
)

Arguments

x

A list returned by sensory.mrCA.

axes

Which dimensions of the MR-CA should be plotted?

alpha.total.bootstrap.test

The alpha risk of the total bootstrap tests. See details.

alpha.ellipse

The alpha risk of the confidence ellipses.

select.desc

A character vector specifying the descriptors to plot. By default, all descriptors are plotted.

rev.x

Should the horizontal plotted dimension be reversed? Useful in case of map comparisons to align products.

rev.y

Should the vertical plotted dimension be reversed? Useful in case of map comparisons to align products.

size.points

The size of the points used to represent the products on the map.

size.lab

The size of the label on the map.

size.head.arrow

The size of the head of the arrows used to represent the descriptors on the map.

expansion

The factor of expansion applied to descriptors coordinates to increase readability.

title

An optional title to be added to the plot.

...

further arguments passed to or from other methods.

Details

  • alpha.total.bootstrap.test: products non-significantly different at the alpha risk of alpha.total.bootstrap.test according to the total bootstrap test are linked by a line on the plot. If these links are not required, alpha.total.bootstrap.test can be set to 1.

Value

A MR-CA factor map

Examples

data(milkchoc)

dim.sig=sensory.mr.dimensionality.test(milkchoc)$dim.sig

res=sensory.mrCA(milkchoc,nbaxes.sig=dim.sig)

plot(res)

MultiResponseR documentation built on March 23, 2026, 5:07 p.m.