sensory.mrCA: Multiple-response Correspondence Analysis (MR-CA) for sensory...

View source: R/sensory.mrCA.R

sensory.mrCAR Documentation

Multiple-response Correspondence Analysis (MR-CA) for sensory data

Description

This function performs the MR-CA of the data as well as the total bootstrap procedure (Cadoret & Husson, 2013) and the pairwise total bootstrap tests as proposed in Castura et al. (2023). The difference with mrCA used with ellipse=TRUE is that the total bootstrap procedure is stratified with respect to subjects in sensory.mrCA.

Usage

sensory.mrCA(data, nboot = 300, nbaxes.sig = Inf)

Arguments

data

A data.frame of evaluations in rows whose first two columns are factors (subject and product) and subsequent columns are binary numeric or integer, each column being a descriptor.

nboot

The number of bootstrapped panel of the total bootstrap procedure.

nbaxes.sig

The number of significant axes returned by sensory.mr.dimensionality.test. By default, all axes are considered significant. See details.

Details

  • nbaxes.sig: The number of significant axes determines the number of axes accounted for while performing the Procrustes rotations of the total bootstrap procedure (Mahieu, Schlich, Visalli, & Cardot, 2021). These same axes are accounted for the pairwise total bootstrap tests.

Value

A list with the following elements:

eigen

Eigenvalues of the MR-CA and their corresponding percentages of inertia

prod.coord

Products coordinates

desc.coord

Descriptors coordinates

svd

Results of the singular value decomposition

bootstrap.replicate.coord

Coordinates of the rotated bootstrap replicates

total.bootstrap.test.pvalues

P-values of the pairwise total bootstrap tests

References

Cadoret, M., & Husson, F. (2013). Construction and evaluation of confidence ellipses applied at sensory data. Food Quality and Preference, 28(1), 106-115.

Castura, J. C., Varela, P., & Næs, T. (2023). Evaluation of complementary numerical and visual approaches for investigating pairwise comparisons after principal component analysis. Food Quality and Preference, 107.

Mahieu, B., Schlich, P., Visalli, M., & Cardot, H. (2021). A multiple-response chi-square framework for the analysis of Free-Comment and Check-All-That-Apply data. Food Quality and Preference, 93.

Examples


data(milkchoc)

dim.sig=sensory.mr.dimensionality.test(milkchoc)$dim.sig

res=sensory.mrCA(milkchoc,nbaxes.sig=dim.sig)

plot(res)

MultiResponseR documentation built on March 23, 2026, 5:07 p.m.